@@ -70,7 +70,28 @@ class FunctionResource(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(FunctionResource.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id_: builtins.str,
+                *,
+                body: builtins.str,
+                name: builtins.str,
+                arg: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence[typing.Union[FunctionResourceArg, typing.Dict[str, typing.Any]]]]] = None,
+                database: typing.Optional[builtins.str] = None,
+                drop_cascade: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                id: typing.Optional[builtins.str] = None,
+                returns: typing.Optional[builtins.str] = None,
+                schema: typing.Optional[builtins.str] = None,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = FunctionResourceConfig(
@@ -102,7 +123,11 @@ class FunctionResource(
         :param value: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(FunctionResource.put_arg)
+            def stub(
+                value: typing.Union[cdktf.IResolvable, typing.Sequence[typing.Union[FunctionResourceArg, typing.Dict[str, typing.Any]]]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         return typing.cast(None, jsii.invoke(self, "putArg", [value]))
 
@@ -196,7 +221,9 @@ class FunctionResource(
     @body.setter
     def body(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FunctionResource, "body").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "body", value)
 
@@ -208,7 +235,9 @@ class FunctionResource(
     @database.setter
     def database(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FunctionResource, "database").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "database", value)
 
@@ -223,7 +252,9 @@ class FunctionResource(
         value: typing.Union[builtins.bool, cdktf.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FunctionResource, "drop_cascade").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "dropCascade", value)
 
@@ -235,7 +266,9 @@ class FunctionResource(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FunctionResource, "id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -247,7 +280,9 @@ class FunctionResource(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FunctionResource, "name").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -259,7 +294,9 @@ class FunctionResource(
     @returns.setter
     def returns(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FunctionResource, "returns").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "returns", value)
 
@@ -271,7 +308,9 @@ class FunctionResource(
     @schema.setter
     def schema(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FunctionResource, "schema").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "schema", value)
 
@@ -302,7 +341,15 @@ class FunctionResourceArg:
         :param name: The argument name. The name may be required for some languages or depending on the argument mode. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/postgresql/r/function#name FunctionResource#name}
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(FunctionResourceArg.__init__)
+            def stub(
+                *,
+                type: builtins.str,
+                default: typing.Optional[builtins.str] = None,
+                mode: typing.Optional[builtins.str] = None,
+                name: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument type", value=type, expected_type=type_hints["type"])
             check_type(argname="argument default", value=default, expected_type=type_hints["default"])
             check_type(argname="argument mode", value=mode, expected_type=type_hints["mode"])
@@ -383,7 +430,13 @@ class FunctionResourceArgList(
         :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(FunctionResourceArgList.__init__)
+            def stub(
+                terraform_resource: cdktf.IInterpolatingParent,
+                terraform_attribute: builtins.str,
+                wraps_set: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
             check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
@@ -395,7 +448,9 @@ class FunctionResourceArgList(
         :param index: the index of the item to return.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(FunctionResourceArgList.get)
+            def stub(index: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument index", value=index, expected_type=type_hints["index"])
         return typing.cast("FunctionResourceArgOutputReference", jsii.invoke(self, "get", [index]))
 
@@ -408,7 +463,9 @@ class FunctionResourceArgList(
     @_terraform_attribute.setter
     def _terraform_attribute(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FunctionResourceArgList, "_terraform_attribute").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "terraformAttribute", value)
 
@@ -421,7 +478,9 @@ class FunctionResourceArgList(
     @_terraform_resource.setter
     def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FunctionResourceArgList, "_terraform_resource").fset)
+            def stub(value: cdktf.IInterpolatingParent) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "terraformResource", value)
 
@@ -434,7 +493,9 @@ class FunctionResourceArgList(
     @_wraps_set.setter
     def _wraps_set(self, value: builtins.bool) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FunctionResourceArgList, "_wraps_set").fset)
+            def stub(value: builtins.bool) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "wrapsSet", value)
 
@@ -451,7 +512,11 @@ class FunctionResourceArgList(
         value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[FunctionResourceArg]]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FunctionResourceArgList, "internal_value").fset)
+            def stub(
+                value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[FunctionResourceArg]]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -475,7 +540,14 @@ class FunctionResourceArgOutputReference(
         :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(FunctionResourceArgOutputReference.__init__)
+            def stub(
+                terraform_resource: cdktf.IInterpolatingParent,
+                terraform_attribute: builtins.str,
+                complex_object_index: jsii.Number,
+                complex_object_is_from_set: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
             check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
@@ -522,7 +594,9 @@ class FunctionResourceArgOutputReference(
     @default.setter
     def default(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FunctionResourceArgOutputReference, "default").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "default", value)
 
@@ -534,7 +608,9 @@ class FunctionResourceArgOutputReference(
     @mode.setter
     def mode(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FunctionResourceArgOutputReference, "mode").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "mode", value)
 
@@ -546,7 +622,9 @@ class FunctionResourceArgOutputReference(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FunctionResourceArgOutputReference, "name").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -558,7 +636,9 @@ class FunctionResourceArgOutputReference(
     @type.setter
     def type(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FunctionResourceArgOutputReference, "type").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "type", value)
 
@@ -575,7 +655,11 @@ class FunctionResourceArgOutputReference(
         value: typing.Optional[typing.Union[FunctionResourceArg, cdktf.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FunctionResourceArgOutputReference, "internal_value").fset)
+            def stub(
+                value: typing.Optional[typing.Union[FunctionResourceArg, cdktf.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -641,7 +725,26 @@ class FunctionResourceConfig(cdktf.TerraformMetaArguments):
         if isinstance(lifecycle, dict):
             lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
         if __debug__:
-            type_hints = typing.get_type_hints(FunctionResourceConfig.__init__)
+            def stub(
+                *,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+                body: builtins.str,
+                name: builtins.str,
+                arg: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence[typing.Union[FunctionResourceArg, typing.Dict[str, typing.Any]]]]] = None,
+                database: typing.Optional[builtins.str] = None,
+                drop_cascade: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                id: typing.Optional[builtins.str] = None,
+                returns: typing.Optional[builtins.str] = None,
+                schema: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
