@@ -36,6 +36,7 @@ class PostgresqlProvider(
         alias: typing.Optional[builtins.str] = None,
         aws_rds_iam_auth: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
         aws_rds_iam_profile: typing.Optional[builtins.str] = None,
+        aws_rds_iam_region: typing.Optional[builtins.str] = None,
         clientcert: typing.Optional[typing.Union["PostgresqlProviderClientcert", typing.Dict[str, typing.Any]]] = None,
         connect_timeout: typing.Optional[jsii.Number] = None,
         database: typing.Optional[builtins.str] = None,
@@ -59,6 +60,7 @@ class PostgresqlProvider(
         :param alias: Alias name. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/postgresql#alias PostgresqlProvider#alias}
         :param aws_rds_iam_auth: Use rds_iam instead of password authentication (see: https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/UsingWithRDS.IAMDBAuth.html). Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/postgresql#aws_rds_iam_auth PostgresqlProvider#aws_rds_iam_auth}
         :param aws_rds_iam_profile: AWS profile to use for IAM auth. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/postgresql#aws_rds_iam_profile PostgresqlProvider#aws_rds_iam_profile}
+        :param aws_rds_iam_region: AWS region to use for IAM auth. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/postgresql#aws_rds_iam_region PostgresqlProvider#aws_rds_iam_region}
         :param clientcert: clientcert block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/postgresql#clientcert PostgresqlProvider#clientcert}
         :param connect_timeout: Maximum wait for connection, in seconds. Zero or not specified means wait indefinitely. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/postgresql#connect_timeout PostgresqlProvider#connect_timeout}
         :param database: The name of the database to connect to in order to conenct to (defaults to ``postgres``). Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/postgresql#database PostgresqlProvider#database}
@@ -76,13 +78,39 @@ class PostgresqlProvider(
         :param username: PostgreSQL user name to connect as. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/postgresql#username PostgresqlProvider#username}
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(PostgresqlProvider.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                alias: typing.Optional[builtins.str] = None,
+                aws_rds_iam_auth: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                aws_rds_iam_profile: typing.Optional[builtins.str] = None,
+                aws_rds_iam_region: typing.Optional[builtins.str] = None,
+                clientcert: typing.Optional[typing.Union[PostgresqlProviderClientcert, typing.Dict[str, typing.Any]]] = None,
+                connect_timeout: typing.Optional[jsii.Number] = None,
+                database: typing.Optional[builtins.str] = None,
+                database_username: typing.Optional[builtins.str] = None,
+                expected_version: typing.Optional[builtins.str] = None,
+                host: typing.Optional[builtins.str] = None,
+                max_connections: typing.Optional[jsii.Number] = None,
+                password: typing.Optional[builtins.str] = None,
+                port: typing.Optional[jsii.Number] = None,
+                scheme: typing.Optional[builtins.str] = None,
+                sslmode: typing.Optional[builtins.str] = None,
+                ssl_mode: typing.Optional[builtins.str] = None,
+                sslrootcert: typing.Optional[builtins.str] = None,
+                superuser: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                username: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         config = PostgresqlProviderConfig(
             alias=alias,
             aws_rds_iam_auth=aws_rds_iam_auth,
             aws_rds_iam_profile=aws_rds_iam_profile,
+            aws_rds_iam_region=aws_rds_iam_region,
             clientcert=clientcert,
             connect_timeout=connect_timeout,
             database=database,
@@ -114,6 +142,10 @@ class PostgresqlProvider(
     def reset_aws_rds_iam_profile(self) -> None:
         return typing.cast(None, jsii.invoke(self, "resetAwsRdsIamProfile", []))
 
+    @jsii.member(jsii_name="resetAwsRdsIamRegion")
+    def reset_aws_rds_iam_region(self) -> None:
+        return typing.cast(None, jsii.invoke(self, "resetAwsRdsIamRegion", []))
+
     @jsii.member(jsii_name="resetClientcert")
     def reset_clientcert(self) -> None:
         return typing.cast(None, jsii.invoke(self, "resetClientcert", []))
@@ -200,6 +232,11 @@ class PostgresqlProvider(
     def aws_rds_iam_profile_input(self) -> typing.Optional[builtins.str]:
         return typing.cast(typing.Optional[builtins.str], jsii.get(self, "awsRdsIamProfileInput"))
 
+    @builtins.property
+    @jsii.member(jsii_name="awsRdsIamRegionInput")
+    def aws_rds_iam_region_input(self) -> typing.Optional[builtins.str]:
+        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "awsRdsIamRegionInput"))
+
     @builtins.property
     @jsii.member(jsii_name="clientcertInput")
     def clientcert_input(self) -> typing.Optional["PostgresqlProviderClientcert"]:
@@ -285,7 +322,9 @@ class PostgresqlProvider(
     @alias.setter
     def alias(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(PostgresqlProvider, "alias").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "alias", value)
 
@@ -302,7 +341,11 @@ class PostgresqlProvider(
         value: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(PostgresqlProvider, "aws_rds_iam_auth").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "awsRdsIamAuth", value)
 
@@ -314,10 +357,26 @@ class PostgresqlProvider(
     @aws_rds_iam_profile.setter
     def aws_rds_iam_profile(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(PostgresqlProvider, "aws_rds_iam_profile").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "awsRdsIamProfile", value)
 
+    @builtins.property
+    @jsii.member(jsii_name="awsRdsIamRegion")
+    def aws_rds_iam_region(self) -> typing.Optional[builtins.str]:
+        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "awsRdsIamRegion"))
+
+    @aws_rds_iam_region.setter
+    def aws_rds_iam_region(self, value: typing.Optional[builtins.str]) -> None:
+        if __debug__:
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "awsRdsIamRegion", value)
+
     @builtins.property
     @jsii.member(jsii_name="clientcert")
     def clientcert(self) -> typing.Optional["PostgresqlProviderClientcert"]:
@@ -329,7 +388,9 @@ class PostgresqlProvider(
         value: typing.Optional["PostgresqlProviderClientcert"],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(PostgresqlProvider, "clientcert").fset)
+            def stub(value: typing.Optional[PostgresqlProviderClientcert]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "clientcert", value)
 
@@ -341,7 +402,9 @@ class PostgresqlProvider(
     @connect_timeout.setter
     def connect_timeout(self, value: typing.Optional[jsii.Number]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(PostgresqlProvider, "connect_timeout").fset)
+            def stub(value: typing.Optional[jsii.Number]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "connectTimeout", value)
 
@@ -353,7 +416,9 @@ class PostgresqlProvider(
     @database.setter
     def database(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(PostgresqlProvider, "database").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "database", value)
 
@@ -365,7 +430,9 @@ class PostgresqlProvider(
     @database_username.setter
     def database_username(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(PostgresqlProvider, "database_username").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "databaseUsername", value)
 
@@ -377,7 +444,9 @@ class PostgresqlProvider(
     @expected_version.setter
     def expected_version(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(PostgresqlProvider, "expected_version").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "expectedVersion", value)
 
@@ -389,7 +458,9 @@ class PostgresqlProvider(
     @host.setter
     def host(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(PostgresqlProvider, "host").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "host", value)
 
@@ -401,7 +472,9 @@ class PostgresqlProvider(
     @max_connections.setter
     def max_connections(self, value: typing.Optional[jsii.Number]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(PostgresqlProvider, "max_connections").fset)
+            def stub(value: typing.Optional[jsii.Number]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "maxConnections", value)
 
@@ -413,7 +486,9 @@ class PostgresqlProvider(
     @password.setter
     def password(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(PostgresqlProvider, "password").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "password", value)
 
@@ -425,7 +500,9 @@ class PostgresqlProvider(
     @port.setter
     def port(self, value: typing.Optional[jsii.Number]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(PostgresqlProvider, "port").fset)
+            def stub(value: typing.Optional[jsii.Number]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "port", value)
 
@@ -437,7 +514,9 @@ class PostgresqlProvider(
     @scheme.setter
     def scheme(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(PostgresqlProvider, "scheme").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "scheme", value)
 
@@ -449,7 +528,9 @@ class PostgresqlProvider(
     @sslmode.setter
     def sslmode(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(PostgresqlProvider, "sslmode").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "sslmode", value)
 
@@ -461,7 +542,9 @@ class PostgresqlProvider(
     @ssl_mode.setter
     def ssl_mode(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(PostgresqlProvider, "ssl_mode").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "sslMode", value)
 
@@ -473,7 +556,9 @@ class PostgresqlProvider(
     @sslrootcert.setter
     def sslrootcert(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(PostgresqlProvider, "sslrootcert").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "sslrootcert", value)
 
@@ -490,7 +575,11 @@ class PostgresqlProvider(
         value: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(PostgresqlProvider, "superuser").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "superuser", value)
 
@@ -502,7 +591,9 @@ class PostgresqlProvider(
     @username.setter
     def username(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(PostgresqlProvider, "username").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "username", value)
 
@@ -519,7 +610,9 @@ class PostgresqlProviderClientcert:
         :param key: The SSL client certificate private key file path. The file must contain PEM encoded data. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/postgresql#key PostgresqlProvider#key}
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(PostgresqlProviderClientcert.__init__)
+            def stub(*, cert: builtins.str, key: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument cert", value=cert, expected_type=type_hints["cert"])
             check_type(argname="argument key", value=key, expected_type=type_hints["key"])
         self._values: typing.Dict[str, typing.Any] = {
@@ -566,6 +659,7 @@ class PostgresqlProviderClientcert:
         "alias": "alias",
         "aws_rds_iam_auth": "awsRdsIamAuth",
         "aws_rds_iam_profile": "awsRdsIamProfile",
+        "aws_rds_iam_region": "awsRdsIamRegion",
         "clientcert": "clientcert",
         "connect_timeout": "connectTimeout",
         "database": "database",
@@ -590,6 +684,7 @@ class PostgresqlProviderConfig:
         alias: typing.Optional[builtins.str] = None,
         aws_rds_iam_auth: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
         aws_rds_iam_profile: typing.Optional[builtins.str] = None,
+        aws_rds_iam_region: typing.Optional[builtins.str] = None,
         clientcert: typing.Optional[typing.Union[PostgresqlProviderClientcert, typing.Dict[str, typing.Any]]] = None,
         connect_timeout: typing.Optional[jsii.Number] = None,
         database: typing.Optional[builtins.str] = None,
@@ -610,6 +705,7 @@ class PostgresqlProviderConfig:
         :param alias: Alias name. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/postgresql#alias PostgresqlProvider#alias}
         :param aws_rds_iam_auth: Use rds_iam instead of password authentication (see: https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/UsingWithRDS.IAMDBAuth.html). Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/postgresql#aws_rds_iam_auth PostgresqlProvider#aws_rds_iam_auth}
         :param aws_rds_iam_profile: AWS profile to use for IAM auth. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/postgresql#aws_rds_iam_profile PostgresqlProvider#aws_rds_iam_profile}
+        :param aws_rds_iam_region: AWS region to use for IAM auth. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/postgresql#aws_rds_iam_region PostgresqlProvider#aws_rds_iam_region}
         :param clientcert: clientcert block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/postgresql#clientcert PostgresqlProvider#clientcert}
         :param connect_timeout: Maximum wait for connection, in seconds. Zero or not specified means wait indefinitely. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/postgresql#connect_timeout PostgresqlProvider#connect_timeout}
         :param database: The name of the database to connect to in order to conenct to (defaults to ``postgres``). Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/postgresql#database PostgresqlProvider#database}
@@ -629,10 +725,34 @@ class PostgresqlProviderConfig:
         if isinstance(clientcert, dict):
             clientcert = PostgresqlProviderClientcert(**clientcert)
         if __debug__:
-            type_hints = typing.get_type_hints(PostgresqlProviderConfig.__init__)
+            def stub(
+                *,
+                alias: typing.Optional[builtins.str] = None,
+                aws_rds_iam_auth: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                aws_rds_iam_profile: typing.Optional[builtins.str] = None,
+                aws_rds_iam_region: typing.Optional[builtins.str] = None,
+                clientcert: typing.Optional[typing.Union[PostgresqlProviderClientcert, typing.Dict[str, typing.Any]]] = None,
+                connect_timeout: typing.Optional[jsii.Number] = None,
+                database: typing.Optional[builtins.str] = None,
+                database_username: typing.Optional[builtins.str] = None,
+                expected_version: typing.Optional[builtins.str] = None,
+                host: typing.Optional[builtins.str] = None,
+                max_connections: typing.Optional[jsii.Number] = None,
+                password: typing.Optional[builtins.str] = None,
+                port: typing.Optional[jsii.Number] = None,
+                scheme: typing.Optional[builtins.str] = None,
+                sslmode: typing.Optional[builtins.str] = None,
+                ssl_mode: typing.Optional[builtins.str] = None,
+                sslrootcert: typing.Optional[builtins.str] = None,
+                superuser: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                username: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument alias", value=alias, expected_type=type_hints["alias"])
             check_type(argname="argument aws_rds_iam_auth", value=aws_rds_iam_auth, expected_type=type_hints["aws_rds_iam_auth"])
             check_type(argname="argument aws_rds_iam_profile", value=aws_rds_iam_profile, expected_type=type_hints["aws_rds_iam_profile"])
+            check_type(argname="argument aws_rds_iam_region", value=aws_rds_iam_region, expected_type=type_hints["aws_rds_iam_region"])
             check_type(argname="argument clientcert", value=clientcert, expected_type=type_hints["clientcert"])
             check_type(argname="argument connect_timeout", value=connect_timeout, expected_type=type_hints["connect_timeout"])
             check_type(argname="argument database", value=database, expected_type=type_hints["database"])
@@ -655,6 +775,8 @@ class PostgresqlProviderConfig:
             self._values["aws_rds_iam_auth"] = aws_rds_iam_auth
         if aws_rds_iam_profile is not None:
             self._values["aws_rds_iam_profile"] = aws_rds_iam_profile
+        if aws_rds_iam_region is not None:
+            self._values["aws_rds_iam_region"] = aws_rds_iam_region
         if clientcert is not None:
             self._values["clientcert"] = clientcert
         if connect_timeout is not None:
@@ -715,6 +837,15 @@ class PostgresqlProviderConfig:
         result = self._values.get("aws_rds_iam_profile")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def aws_rds_iam_region(self) -> typing.Optional[builtins.str]:
+        '''AWS region to use for IAM auth.
+
+        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/postgresql#aws_rds_iam_region PostgresqlProvider#aws_rds_iam_region}
+        '''
+        result = self._values.get("aws_rds_iam_region")
+        return typing.cast(typing.Optional[builtins.str], result)
+
     @builtins.property
     def clientcert(self) -> typing.Optional[PostgresqlProviderClientcert]:
         '''clientcert block.
